# Copyright © 2022 Arrikto Inc.  All Rights Reserved.

"""PyTorch Model Definition.

This script defines a simple PyTorch CNN.
"""

import torch
import torch.nn as nn
import torch.nn.functional as f


class Net(nn.Module):
    """Define CNN model."""

    def __init__(self):
        super(Net, self).__init__()
        self.conv1 = nn.Conv2d(3, 6, 5)
        self.conv2 = nn.Conv2d(6, 16, 5)
        self.fc1 = nn.Linear(16 * 5 * 5, 120)
        self.fc2 = nn.Linear(120, 84)
        self.fc3 = nn.Linear(84, 10)

    def forward(self, x):
        x = self.conv1(x)
        x = f.relu(x)
        x = f.max_pool2d(x, kernel_size=2)
        x = self.conv2(x)
        x = f.relu(x)
        x = f.max_pool2d(x, kernel_size=2)

        x = torch.flatten(x, 1)
        x = self.fc1(x)
        x = f.relu(x)
        x = self.fc2(x)
        x = f.relu(x)
        x = self.fc3(x)

        return x
